@@ -526,7 +526,7 @@ SEXP mcmc(SEXP Y, SEXP X, SEXP Rprobinit, SEXP Rmodeldim, SEXP incint, SEXP Ralp
 	} else {
 		SET_VECTOR_ELT(ANS, 7, beta);
 	}
-	SET_STRING_ELT(ANS_names, 7, mkChar("ols"));
+	SET_STRING_ELT(ANS_names, 7, mkChar("mle"));
 
 	if (nUnique < nModels) {
 		SEXP seP = PROTECT(allocVector(VECSXP, nUnique));
@@ -540,7 +540,7 @@ SEXP mcmc(SEXP Y, SEXP X, SEXP Rprobinit, SEXP Rmodeldim, SEXP incint, SEXP Ralp
 	} else {
 		SET_VECTOR_ELT(ANS, 8, se);
 	}
-	SET_STRING_ELT(ANS_names, 8, mkChar("ols.se"));
+	SET_STRING_ELT(ANS_names, 8, mkChar("mle.se"));
 
 	if (nUnique < nModels) {
 		SEXP shrinkageP = PROTECT(allocVector(REALSXP, nUnique));
